@@ -878,7 +878,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -898,7 +898,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -979,7 +979,7 @@ def _cast(typ, value):
 class contentContainerType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('ident', 'xs:string', 0, 1, {'use': 'optional'}),
+        MemberSpec_('ident', 'xs:string', 0, 1, {'use': 'optional', 'name': 'ident'}),
         MemberSpec_('content', 'contentType', 1, 1, {'maxOccurs': 'unbounded', 'minOccurs': '0', 'name': 'content', 'type': 'contentType'}, None),
     ]
     subclass = None
