@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.8.8 (default, Feb 24 2021, 21:46:12)  [GCC 7.3.0]
+# Python 3.8.11 (default, Aug  3 2021, 15:09:35)  [GCC 7.5.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -36,10 +36,7 @@ import re as re_
 import base64
 import datetime as datetime_
 import decimal as decimal_
-try:
-    from lxml import etree as etree_
-except ModulenotfoundExp_ :
-    from xml.etree import ElementTree as etree_
+from lxml import etree as etree_
 
 
 Validate_simpletypes_ = True
@@ -102,7 +99,7 @@ def parsexmlstring_(instring, parser=None, **kwargs):
 # Additionally, the generatedsnamespaces module can contain a python
 # dictionary named GenerateDSNamespaceTypePrefixes that associates element
 # types with the namespace prefixes that are to be added to the
-# "xsi:type" attribute value.  See the exportAttributes method of
+# "xsi:type" attribute value.  See the _exportAttributes method of
 # any generated element type and the generation of "xsi:type" for an
 # example of the use of this table.
 # An example table:
@@ -179,8 +176,13 @@ except ModulenotfoundExp_ :
 try:
     from generatedssuper import GeneratedsSuper
 except ModulenotfoundExp_ as exp:
+    try:
+        from generatedssupersuper import GeneratedsSuperSuper
+    except ModulenotfoundExp_ as exp:
+        class GeneratedsSuperSuper(object):
+            pass
     
-    class GeneratedsSuper(object):
+    class GeneratedsSuper(GeneratedsSuperSuper):
         __hash__ = object.__hash__
         tzoff_pattern = re_.compile(r'(\+|-)((0\d|1[0-3]):[0-5]\d|14:00)$')
         class _FixedOffsetTZ(datetime_.tzinfo):
@@ -876,7 +878,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -896,7 +898,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -977,15 +979,15 @@ def _cast(typ, value):
 class GetUserReq(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('sequence', 'xsd:unsignedLong', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value01', 'xsd:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value02', 'xsd:integer', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value03', 'xsd:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value04', 'xsd:integer', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value05', 'xsd:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value06', 'xsd:integer', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value07', 'xsd:integer', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value08', 'xsd:string', 0, 1, {'use': 'optional'}),
+        MemberSpec_('sequence', 'xsd:unsignedLong', 0, 1, {'use': 'optional', 'name': 'sequence'}),
+        MemberSpec_('value01', 'xsd:string', 0, 1, {'use': 'optional', 'name': 'value01'}),
+        MemberSpec_('value02', 'xsd:integer', 0, 1, {'use': 'optional', 'name': 'value02'}),
+        MemberSpec_('value03', 'xsd:string', 0, 1, {'use': 'optional', 'name': 'value03'}),
+        MemberSpec_('value04', 'xsd:integer', 0, 1, {'use': 'optional', 'name': 'value04'}),
+        MemberSpec_('value05', 'xsd:string', 0, 1, {'use': 'optional', 'name': 'value05'}),
+        MemberSpec_('value06', 'xsd:integer', 0, 1, {'use': 'optional', 'name': 'value06'}),
+        MemberSpec_('value07', 'xsd:integer', 0, 1, {'use': 'optional', 'name': 'value07'}),
+        MemberSpec_('value08', 'xsd:string', 0, 1, {'use': 'optional', 'name': 'value08'}),
         MemberSpec_('returnedTags', 'xsd:string', 0, 1, {'minOccurs': '0', 'name': 'returnedTags', 'type': 'xsd:string'}, None),
     ]
     subclass = None
@@ -1071,7 +1073,7 @@ class GetUserReq(GeneratedsSuper):
         return self.value08
     def set_value08(self, value08):
         self.value08 = value08
-    def hasContent_(self):
+    def _hasContent(self):
         if (
             self.returnedTags is not None
         ):
@@ -1093,15 +1095,15 @@ class GetUserReq(GeneratedsSuper):
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='GetUserReq')
-        if self.hasContent_():
+        self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='GetUserReq')
+        if self._hasContent():
             outfile.write('>%s' % (eol_, ))
-            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='GetUserReq', pretty_print=pretty_print)
+            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='GetUserReq', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='GetUserReq'):
+    def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='GetUserReq'):
         if self.sequence is not None and 'sequence' not in already_processed:
             already_processed.add('sequence')
             outfile.write(' sequence="%s"' % self.gds_format_integer(self.sequence, input_name='sequence'))
@@ -1129,7 +1131,7 @@ class GetUserReq(GeneratedsSuper):
         if self.value08 is not None and 'value08' not in already_processed:
             already_processed.add('value08')
             outfile.write(' value08=%s' % (self.gds_encode(self.gds_format_string(quote_attrib(self.value08), input_name='value08')), ))
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='GetUserReq', fromsubclass_=False, pretty_print=True):
+    def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='GetUserReq', fromsubclass_=False, pretty_print=True):
         if pretty_print:
             eol_ = '\n'
         else:
@@ -1144,12 +1146,12 @@ class GetUserReq(GeneratedsSuper):
             self.gds_elementtree_node_ = node
         already_processed = set()
         self.ns_prefix_ = node.prefix
-        self.buildAttributes(node, node.attrib, already_processed)
+        self._buildAttributes(node, node.attrib, already_processed)
         for child in node:
             nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
-            self.buildChildren(child, node, nodeName_, gds_collector_=gds_collector_)
+            self._buildChildren(child, node, nodeName_, gds_collector_=gds_collector_)
         return self
-    def buildAttributes(self, node, attrs, already_processed):
+    def _buildAttributes(self, node, attrs, already_processed):
         value = find_attr_value_('sequence', node)
         if value is not None and 'sequence' not in already_processed:
             already_processed.add('sequence')
@@ -1186,7 +1188,7 @@ class GetUserReq(GeneratedsSuper):
         if value is not None and 'value08' not in already_processed:
             already_processed.add('value08')
             self.value08 = value
-    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
+    def _buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
         if nodeName_ == 'returnedTags':
             value_ = child_.text
             value_ = self.gds_parse_string(value_, node, 'returnedTags')
@@ -1269,7 +1271,7 @@ def parse(inFileName, silence=False, print_warnings=True):
 
 
 def parseEtree(inFileName, silence=False, print_warnings=True,
-               mapping=None, nsmap=None):
+               mapping=None, reverse_mapping=None, nsmap=None):
     parser = None
     doc = parsexml_(inFileName, parser)
     gds_collector = GdsCollector_()
@@ -1280,12 +1282,15 @@ def parseEtree(inFileName, silence=False, print_warnings=True,
         rootClass = GetUserReq
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
-    # Enable Python to collect the space used by the DOM.
     if mapping is None:
         mapping = {}
+    if reverse_mapping is None:
+        reverse_mapping = {}
     rootElement = rootObj.to_etree(
-        None, name_=rootTag, mapping_=mapping, nsmap_=nsmap)
-    reverse_mapping = rootObj.gds_reverse_node_mapping(mapping)
+        None, name_=rootTag, mapping_=mapping,
+        reverse_mapping_=reverse_mapping, nsmap_=nsmap)
+    reverse_node_mapping = rootObj.gds_reverse_node_mapping(mapping)
+    # Enable Python to collect the space used by the DOM.
     if not SaveElementTreeNode:
         doc = None
         rootNode = None
@@ -1302,7 +1307,7 @@ def parseEtree(inFileName, silence=False, print_warnings=True,
             len(gds_collector.get_messages()), ))
         gds_collector.write_messages(sys.stderr)
         sys.stderr.write(separator)
-    return rootObj, rootElement, mapping, reverse_mapping
+    return rootObj, rootElement, mapping, reverse_node_mapping
 
 
 def parseString(inString, silence=False, print_warnings=True):
