@@ -87,6 +87,13 @@ $commands = [
   "diff -u decimal_format1_sup.py decimal_format2_sup.py",
   "diff -u derived_types1_sub.py derived_types2_sub.py",
   "diff -u derived_types1_sup.py derived_types2_sup.py",
+  "diff -u simpletype_list1_sub.py simpletype_list2_sub.py",
+  "diff -u simpletype_list1_sup.py simpletype_list2_sup.py",
+  "diff -u relative_import1_sup.py relative_import2_sup.py",
+  "diff -u relative_import1_sub.py relative_import2_sub.py",
+  "diff -u anycontent1_sup.py anycontent2_sup.py",
+  "diff -u anycontent1_sub.py anycontent2_sub.py",
+  "diff -u doc_strings1_sub.py doc_strings2_sub.py",
 ]
 
 def check
