@@ -877,7 +877,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -897,7 +897,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -1282,8 +1282,8 @@ class classBType(GeneratedsSuper):
 class innerType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('attrA1', 'xs:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('attrA2', 'xs:string', 0, 1, {'use': 'optional'}),
+        MemberSpec_('attrA1', 'xs:string', 0, 1, {'use': 'optional', 'name': 'attrA1'}),
+        MemberSpec_('attrA2', 'xs:string', 0, 1, {'use': 'optional', 'name': 'attrA2'}),
     ]
     subclass = None
     superclass = None
@@ -1386,8 +1386,8 @@ class innerType(GeneratedsSuper):
 class innerType1(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('attrB1', 'xs:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('attrB2', 'xs:string', 0, 1, {'use': 'optional'}),
+        MemberSpec_('attrB1', 'xs:string', 0, 1, {'use': 'optional', 'name': 'attrB1'}),
+        MemberSpec_('attrB2', 'xs:string', 0, 1, {'use': 'optional', 'name': 'attrB2'}),
     ]
     subclass = None
     superclass = None
