@@ -873,7 +873,7 @@ class MixedContainer:
 ##                 self.name,
 ##                 base64.b64encode(self.value),
 ##                 self.name))
-##     def to_etree(self, element, mapping_=None, nsmap_=None):
+##     def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
 ##         if self.category == MixedContainer.CategoryText:
 ##             # Prevent exporting empty content as empty lines.
 ##             if self.value.strip():
@@ -893,7 +893,7 @@ class MixedContainer:
 ##             subelement.text = self.to_etree_simple()
 ##         else:    # category == MixedContainer.CategoryComplex
 ##             self.value.to_etree(element)
-##     def to_etree_simple(self, mapping_=None, nsmap_=None):
+##     def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
 ##         if self.content_type == MixedContainer.TypeString:
 ##             text = self.value
 ##         elif (self.content_type == MixedContainer.TypeInteger or
@@ -1034,9 +1034,9 @@ class peopleType(GeneratedsSuper):
 class personType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('value', 'xs:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('id', 'xs:integer', 0, 1, {'use': 'optional'}),
-        MemberSpec_('ratio', 'xs:float', 0, 1, {'use': 'optional'}),
+        MemberSpec_('value', 'xs:string', 0, 1, {'use': 'optional', 'name': 'value'}),
+        MemberSpec_('id', 'xs:integer', 0, 1, {'use': 'optional', 'name': 'id'}),
+        MemberSpec_('ratio', 'xs:float', 0, 1, {'use': 'optional', 'name': 'ratio'}),
         MemberSpec_('name', 'xs:string', 0, 0, {'name': 'name', 'type': 'xs:string'}, None),
         MemberSpec_('interest', 'xs:string', 1, 0, {'maxOccurs': 'unbounded', 'name': 'interest', 'type': 'xs:string'}, None),
         MemberSpec_('category', 'xs:integer', 0, 1, {'minOccurs': '0', 'name': 'category', 'type': 'xs:integer'}, None),
