@@ -879,7 +879,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -899,7 +899,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -980,13 +980,13 @@ def _cast(typ, value):
 class IdentifierType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('schemeID', 'xsd:normalizedString', 0, 1, {'use': 'optional'}),
-        MemberSpec_('schemeName', 'xsd:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('schemeAgencyID', 'xsd:normalizedString', 0, 1, {'use': 'optional'}),
-        MemberSpec_('schemeAgencyName', 'xsd:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('schemeVersionID', 'xsd:normalizedString', 0, 1, {'use': 'optional'}),
-        MemberSpec_('schemeDataURI', 'xsd:anyURI', 0, 1, {'use': 'optional'}),
-        MemberSpec_('schemeURI', 'xsd:anyURI', 0, 1, {'use': 'optional'}),
+        MemberSpec_('schemeID', 'xsd:normalizedString', 0, 1, {'use': 'optional', 'name': 'schemeID'}),
+        MemberSpec_('schemeName', 'xsd:string', 0, 1, {'use': 'optional', 'name': 'schemeName'}),
+        MemberSpec_('schemeAgencyID', 'xsd:normalizedString', 0, 1, {'use': 'optional', 'name': 'schemeAgencyID'}),
+        MemberSpec_('schemeAgencyName', 'xsd:string', 0, 1, {'use': 'optional', 'name': 'schemeAgencyName'}),
+        MemberSpec_('schemeVersionID', 'xsd:normalizedString', 0, 1, {'use': 'optional', 'name': 'schemeVersionID'}),
+        MemberSpec_('schemeDataURI', 'xsd:anyURI', 0, 1, {'use': 'optional', 'name': 'schemeDataURI'}),
+        MemberSpec_('schemeURI', 'xsd:anyURI', 0, 1, {'use': 'optional', 'name': 'schemeURI'}),
         MemberSpec_('valueOf_', 'xsd:normalizedString', 0),
     ]
     subclass = None
